# BEGIN COPYRIGHT BLOCK
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# (C) 2007 Red Hat, Inc.
# All rights reserved.
# END COPYRIGHT BLOCK

###############################################################################
###                          D E F I N I T I O N S                          ###
###############################################################################

## Entity Definitions
%define base_entity       Red Hat
%define base_prefix       pki
%define base_ui_prefix    redhat

## Product Definitions
%define base_system       Certificate System
%define base_product      Token Processing System User Interface
%define base_component    tps-ui
%define base_pki          %{base_entity} %{base_system}

## Package Header Definitions
%define base_name         %{base_ui_prefix}-%{base_prefix}-%{base_component}
%define base_version      8.0.2
%define base_release      1
%define base_phase        %{nil}
%define base_group        System Environment/Base
%define base_vendor       Red Hat, Inc.
%define base_license      GPLv2 with exceptions
%define base_packager     %{base_vendor} <http://bugzilla.redhat.com/bugzilla>
%define base_summary      %{base_pki} - %{base_product}
%define base_url          http://www.redhat.com/certificate_system

## Helper Definitions
%define pki_ca            %{base_entity} Certificate Authority
%define pki_drm           %{base_entity} Data Recovery Manager
%define pki_ds            %{base_entity} Directory Server
%define pki_ocsp          %{base_entity} Online Certificate Status Protocol Manager
%define pki_ra            %{base_entity} Registration Authority
%define pki_tks           %{base_entity} Token Key Service
%define pki_tps           %{base_entity} Token Processing System

## Don't build the debug packages
%define debug_package     %{nil}


##===================##
## Linux Definitions ##
##===================##
%ifos Linux
## A distribution model is required on certain Linux operating systems!
##
## check for a pre-defined distribution model
%define undefined_distro  %(test "%{dist}" = "" && echo 1 || echo 0)
%if %{undefined_distro}
%define is_fedora         %(test -e /etc/fedora-release && echo 1 || echo 0)
%if %{is_fedora}
## define a default distribution model on Fedora Linux
%define dist_prefix       .fc
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/fedora-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%else
%define is_redhat         %(test -e /etc/redhat-release && echo 1 || echo 0)
%if %{is_redhat}
## define a default distribution model on Red Hat Linux
%define dist_prefix       .el
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/redhat-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%endif
%endif
%endif
%endif



###############################################################################
###                       P A C K A G E   H E A D E R                       ###
###############################################################################

Name:           %{base_name}
Version:        %{base_version}
Release:        %{base_release}%{?base_phase}%{?dist}
Summary:        %{base_summary}
Vendor:         %{base_vendor}
URL:            %{base_url}
License:        %{base_license}
Packager:       %{base_packager}
Group:          %{base_group}


## Without AutoReqProv: no, rpmbuild finds all sorts of crazy
## dependencies that we don't care about, and refuses to install
AutoReqProv:    no

BuildArch:      noarch
BuildRoot:      %{_builddir}/%{base_name}-root


## NOTE:  This spec file may require a specific JDK, "gcc", and/or "gcc-c++"
##        packages as well as the "rpm" and "rpm-build" packages.
##
##        Technically, "ant" should not need to be in "BuildRequires" since
##        it is the Java equivalent of "make" (and/or "Autotools").
##
BuildRequires:  ant >= 1.6.2

## Without Requires something, rpmbuild will abort!
Requires:       bash >= 3.0
Provides:       %{base_prefix}-%{base_component}


## This package is non-relocatable!
#Prefix:

Source0:        %{base_name}-%{base_version}.tar.gz

## This package currently contains no patches!
#Patch0:


%description
%{base_pki} is an enterprise software system designed
to manage enterprise Public Key Infrastructure (PKI) deployments.

The %{base_entity} %{base_product} contains the graphical
user interface for the %{pki_tps}.



###############################################################################
###                  P R E P A R A T I O N   &   S E T U P                  ###
###############################################################################

## On Linux systems, prep and setup expect there to be a Source file
## in the /usr/src/redhat/SOURCES directory - it will be unpacked
## in the _builddir (not BuildRoot)
%prep


%setup -q


## This package currently contains no patches!
#%patch0
# patches



###############################################################################
###                        B U I L D   P R O C E S S                        ###
###############################################################################

%build
ant -Dspecfile=%{base_name}.spec



###############################################################################
###                 I N S T A L L A T I O N   P R O C E S S                 ###
###############################################################################

%install
cd dist/binary
unzip %{name}-%{version}.zip -d ${RPM_BUILD_ROOT}



###############################################################################
###                      C L E A N U P   P R O C E S S                      ###
###############################################################################

%clean
rm -rf ${RPM_BUILD_ROOT}



###############################################################################
###  P R E  &  P O S T   I N S T A L L / U N I N S T A L L   S C R I P T S  ###
###############################################################################

## This package currently contains no pre-installation process!
#%pre


## This package currently contains no post-installation process!
#%post


## This package currently contains no pre-uninstallation process!
#%preun


## This package currently contains no post-uninstallation process!
#%postun



###############################################################################
###   I N V E N T O R Y   O F   F I L E S   A N D   D I R E C T O R I E S   ### 
###############################################################################

%files
%attr(-,root,root)     %{_datadir}/doc/%{base_name}-%{base_version}/*
%attr(-,root,root)     %{_datadir}/%{base_prefix}/*



###############################################################################
###                            C H A N G E L O G                            ###
###############################################################################

%changelog
* Thu Sep 9 2010 Ade Lee <alee@redhat.com> 8.0.2-1
- Bugzilla Bug #609331 - Should not be able to manually change the status
  on a token marked as permanently lost or destroyed - fix confirmation page
* Thu Aug 12 2010 Ade Lee <alee@redhat.com> 8.0.1-1
- Bugzilla Bug #609331 - Should not be able to manually change the status
  on a token marked as permanently lost or destroyed
* Mon Jul 13 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-33
- Bugzilla Bug #511136 -  Integrate EULA file into RHCS
- Release Candidate 4 build
* Wed Jul 8 2009 Kevin Wright <kwright@redhat.com> 8.0.0-32
- Bugzilla Bug #510352 -  Release Candidate 3 build
* Thu Jul 2 2009 Kevin Wright <kwright@redhat.com> 8.0.0-31
- Bugzilla Bug #509447 -  Release Candidate 2 build
* Wed Jul 1 2009 Ade Lee <alee@redhat.com> 8.0.0-30
- Bugzilla Bug #508421 -   Remove Token/Cert/ Activity List page
* Thu Jun 25 2009 Kevin Wright <kwright@redhat.com> 8.0.0-29
- Bugzilla Bug #508179 -  Remove base_phase ".beta" tag
* Fri Jun 19 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-28
- Bugzilla Bug #506867 -  Provide custom error page for HTTP STATUS 500
* Mon Jun 15 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-27
- Bugzilla Bug #502908 -  Current page not found handling is a Cat 2 finding
  with the Tomcat STIG
* Sat Jun 13 2009 Jack Magne <jmagne@redhat.com> 8.0.0-26
- Bugzilla Bug #491019 - Security Officer: Format Card operation to format a user card 
  also formats a security officer card.
* Tue Jun 9 2009 Ade Lee <alee@redhat.com> 8.0.0-25
* Bugzilla Bug #504042 - unable to list users that where created with a space in the name
* Mon Jun 1 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-24
- Bugzilla Bug #503255 -  Fix confusing "Security Domain" message when using 
  "status"
* Wed May 20 2009 Ade Lee <alee@redhat.com> 8.0.0-23
- Bugzilla Bug #497583 -  web wizard tps - menu highlight and label typo
* Sat May 16 2009 Jack Magne <jmagne@redhat.com> 8.0.0-22
- Bugzilla Bug #491019 - Security Officer token can get formatted with
  user format page.
* Thu May 14 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-21
- Bugzilla Bug #500498 -  CA installation wizard doesn't install
  administrator cert into browser on Firefox 3
* Fri May 8 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-20
- Bugzilla Bug #492735 -  Configuration wizard stores certain incorrect
  port values within TPS "CS.cfg" . . .
* Tue May 5 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-19
- Bugzilla Bug #492735 -  Configuration wizard stores certain incorrect
  port values within TPS "CS.cfg" . . .
- Bugzilla Bug #495597 -  Unable to access Agent page using a configured
  CA/KRA containing an HSM

* Mon May 4 2009 Kevin Wright <kwright@redhat.com> 8.0.0-18
- Bugzilla Bug #499030 -  Beta 2 Release

* Tue Apr 21 2009 Ade Lee <alee@redhat.com> 8.0.0-17
- Bugzilla Bug #496687 - TPS admin page doesn't list users added to the roles
* Sat Mar 28 2009 Jack Magne <jmagne@redhat.com> 8.0.0-16
- Bugzilla Bug #491227 - Reg user can get to Security Officer pages.
* Fri Mar 27 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-15
- Bugzilla Bug #492502 -  Redefine "base_phase" from ".alpha" to ".beta"
* Tue Mar 24 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-14
- Bugzilla Bug #488388 -  copyright notices - remove from UI
- Bugzilla Bug #440543 -  CA's web-services page needs improvements
* Tue Mar 24 2009 Ade Lee <alee@redhat.com> 8.0.0-13
- Bugzilla 490452 support for signed audit in UI
* Fri Mar 20 2009 Ade Lee <alee@redhat.com> 8.0.0-12
- Bugzilla 489318 TPS does not list more than 20 activities
* Wed Mar 4 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-11
- Bugzilla Bug #440344 -  Installation page should tell admins to use
  "service", not "/etc/init.d" on Linux
* Sat Feb 28 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-10
- Bugzilla Bug #487896 - Introduce optional 'base_phase' release tag to
  denote ".alpha", ".beta", etc.

* Fri Feb 27 2009 Ade Lee <alee@redhat.com> 8.0.0-9
- Bugzilla 224835 and 367171: Allow cert nicknames to be edited and sizepanel fixes
* Thu Feb 26 2009 Ade Lee <alee@redhat.com> 8.0.0-8
- Bugzilla 484275: TPS roles defined 
* Thu Feb 26 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-7
- Bugzilla Bug #458337 -  Provide separate listening ports for CS
* Wed Feb 25 2009 Jack Magne <jmagne@redhat.com> 8.0.0-6
- Bugzilla Bug #445274 - Make esc security officer mode work.
* Wed Feb 11 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-5
- Bugzilla Bug #467155 - Change "renameTo" to "cp -p "
* Tue Jan 27 2009 Ade Lee <alee@redhat.com> 8.0.0-4
- Bugzilla Bug #479092: TPS roles enhancements
* Sat Nov 29 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-3
- Aligned RHEL 5, RHEL 4, and Solaris 9 "base_release" numbers
- Bugzilla Bug #445402 - Changed "base_url" from
                         "http://www.redhat.com/software/rha/certificate" to
                         "http://www.redhat.com/certificate_system"

* Sat Nov 22 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-2
- Bugzilla Bug #472305 - "equality" tests in all spec files need to be fixed
- Bumped "java" and "java-devel" 1.4.2 and 1.5.0 dependencies to 1.6.0
- Changed "java-sdk" to "java-devel" for consistency

* Wed May 23 2007 Kevin McCarthy <kmccarth@redhat.com> 8.0.0-1
- Bump to version 8.0.0

* Thu May 17 2007 Thomas Kwan <nkwan@redhat.com> 1.0.0-1
- Initial Revision

